@@ -33,6 +33,14 @@ public:
     QPixmap pixmap(QChar icon, const QSize &size, const QColor &color) const;
     QPixmap pixmap(Icon icon, const QSize &size, const QColor &color) const;
 
+    void addThemeOverride(QChar character, const QString &iconNameInTheme);
+    void addThemeOverride(Icon icon, const QString &iconNameInTheme);
+    void addOverride(QChar character, const QIcon &override);
+    void addOverride(Icon icon, const QIcon &override);
+    void clearOverrides();
+
+    static Renderer &global();
+
 private:
     std::unique_ptr<Renderer::InternalData> m_d;
 };
@@ -45,6 +53,22 @@ inline void Renderer::render(Icon icon, QPainter *painter, const QRect &rect, co
     render(QChar(static_cast<IconBaseType>(icon)), painter, rect, color);
 }
 
+/*!
+ * \brief Uses the icon from the current icon theme obtained via QIcon::fromTheme() for \a icon if it exists.
+ */
+inline void Renderer::addThemeOverride(Icon icon, const QString &iconNameInTheme)
+{
+    addThemeOverride(QChar(static_cast<IconBaseType>(icon)), iconNameInTheme);
+}
+
+/*!
+ * \brief Uses the specified \a override icon for \a icon if it is not null.
+ */
+inline void Renderer::addOverride(Icon icon, const QIcon &override)
+{
+    addOverride(QChar(static_cast<IconBaseType>(icon)), override);
+}
+
 } // namespace QtForkAwesome
 
 #endif // QT_FORK_AWESOME_RENDERER
